==> dif-core-2.1.7-20150513.172652-1-sources.jar: pt/digitalis/dif/controller/objects/SSOInfo.java <==
/**
 * - Digitalis Internal Framework v2.0 - (C) 2008, Digitalis Informatica.
 *
 * Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos num.9 -
 * Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21
 * 4408999 http://www.digitalis.pt
 */
package pt.digitalis.dif.controller.objects;

/**
 * A SSO class for passing the username and password to auto login.
 * Is used by custom dispatchers that will implement specific SSOs.
 *
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 *
 */
public class SSOInfo {
    /** the username */
    private String username;

    /** the password */
    private String password;

    /** the system */
    private String system;

    /** the action */
    private SSOActionEnum action;

    /**
     * @return the username
     */
    public String getUsername()
    {
        return username;
    }

    /**
     * @param username the username to set
     */
    public void setUsername(String username)
    {
        this.username = username;
    }

    /**
     * @return the password
     */
    public String getPassword()
    {
        return password;
    }

    /**
     * @param password the password to set
     */
    public void setPassword(String password)
    {
        this.password = password;
    }

    /**
     * @return the system
     */
    public String getSystem()
    {
        return system;
    }

    /**
     * @param system
     */
    public void setSystem(String system)
    {
        this.system = system;
    }
    /**
     * @return the system
     */
    public SSOActionEnum getAction()
    {
        return action;
    }

    /**
     * @param action
     */
    public void setAction(SSOActionEnum action)
    {
        this.action = action;
    }
}

==> dif-core-2.6.0-sources.jar: pt/digitalis/dif/controller/objects/SSOInfo.java <==
/**
 * - Digitalis Internal Framework v2.0 - (C) 2008, Digitalis Informatica. Distribuicao e Gestao de Informatica, Lda.
 * Estrada de Paco de Arcos num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999
 * http://www.digitalis.pt
 */
package pt.digitalis.dif.controller.objects;

/**
 * A SSO class for passing the username and password to auto login. Is used by custom dispatchers that will implement
 * specific SSOs.
 *
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 */
public class SSOInfo
{

    /** the action */
    private SSOActionEnum action;

    /** the password */
    private String password;

    /** the system */
    private String system;

    /** the username */
    private String username;

    /**
     * @return the system
     */
    public SSOActionEnum getAction()
    {
        return action;
    }

    /**
     * @param action
     */
    public void setAction(SSOActionEnum action)
    {
        this.action = action;
    }

    /**
     * @return the password
     */
    public String getPassword()
    {
        return password;
    }

    /**
     * @param password the password to set
     */
    public void setPassword(String password)
    {
        this.password = password;
    }

    /**
     * @return the system
     */
    public String getSystem()
    {
        return system;
    }

    /**
     * @param system
     */
    public void setSystem(String system)
    {
        this.system = system;
    }

    /**
     * @return the username
     */
    public String getUsername()
    {
        return username;
    }

    /**
     * @param username the username to set
     */
    public void setUsername(String username)
    {
        this.username = username;
    }
}
